@@ -78,7 +78,7 @@ class Backup:
                 username,
                 db_name,
                 '-E UTF-8',
-                ' '.join(f'-t {table_name}' for table_name in table_names),
+                ' '.join(f'-t "{table_name}"' for table_name in table_names),
                 _out=f)
 
         logger.info('Finished creation of backup')
